@@ -8,6 +8,7 @@ from .reabb import list_word_abb
 from .reoov import format_word, check_oov_word
 from .clean_text import clean_line
 import re
+import validators
 # from nltk import word_tokenize
 
 
@@ -57,6 +58,13 @@ def extract_word_tag(txt, txt_tag):
             word_tags.append('B-{}'.format(t))
             word_tags.extend(['I-{}'.format(t)] * (len(list_words) - 1))
 
+    for i, (w, t) in enumerate(zip(words, word_tags)):
+        if t.endswith('oov'):
+            if validators.email(w):
+                word_tags[i] = 'B-email'
+            elif validators.domain(w) or validators.url(w):
+                word_tags[i] = 'B-url'
+
     return words, word_tags
 
 
@@ -175,10 +183,11 @@ def tagging(txt, debug=False):
 
 
 if __name__ == "__main__":
-    input_text = 'Tiền thưởng U23 Việt Nam vượt mốc 23 tỷ đồng , Thành công tại giải U23 châu Á giúp tuyển U23 Việt Nam đón cơn mưa tiền thưởng , hiện vật và dịch vụ .'
+    input_text = 'tôi có 80000$ sinh vào năm 1999 email binh123tam@gmail.com link http://1234.cn hoặc 123.vn'
+    # input_text = 'tôi sinh năm 9887 người là con số đẹp'
     # input_text = '152/2017/NĐ-CP của ttcp 13 kb ngày 9/10/2021 -87,5 wh'
     # input_text = ' '.join(word_tokenize(input_text))
     print(input_text)
-    tags = tagging(input_text)
+    tags = tagging(input_text, debug=True)
     for t, p_i in zip(*tags):
         print(t, p_i)
