@@ -4,7 +4,7 @@ re_id_list = [
     "[\d]+[\/\-]*[\w]+[\/\-]*[\w]*", #1673/QĐ-UBND, 50/2014/TT-BGTVT
     "[\d]+[\/\-]+[\d]*[\/\-]*[a-zđ\-\/]+",
     "\d{7,}",
-    "[\d.\/\-\.,]+",
+    "[\d.\/\-\.,]{2,}",
     "\d{2}[a-z]{1,3}-\d{2,4}[\.]*\d*",
     "[a-z]+[\-/]\d+",
 ]
\ No newline at end of file
